api.assets.v1.test_helpers.vulnerability package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.vulnerability package

## Submodules

## api.assets.v1.test_helpers.vulnerability.add_asset_vulnerability module

`api.assets.v1.test_helpers.vulnerability.add_asset_vulnerability.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.add_asset_vulnerability.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.add_asset_vulnerability.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.add_asset_vulnerability.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.delete_asset_vulnerability module

`api.assets.v1.test_helpers.vulnerability.delete_asset_vulnerability.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.delete_asset_vulnerability.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.delete_asset_vulnerability.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.delete_asset_vulnerability.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.get_asset_vulnerability module

`api.assets.v1.test_helpers.vulnerability.get_asset_vulnerability.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.get_asset_vulnerability.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.get_asset_vulnerability.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.get_asset_vulnerability.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.resolve_asset_vulnerability module

`api.assets.v1.test_helpers.vulnerability.resolve_asset_vulnerability.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+/resolve, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.resolve_asset_vulnerability.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+/resolve, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.resolve_asset_vulnerability.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+/resolve, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.resolve_asset_vulnerability.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+/resolve, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities module

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/search, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/search, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/search, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/search, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities_simplified module

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities_simplified.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities_simplified.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities_simplified.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerabilities_simplified.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.search_asset_vulnerability_statistics module

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerability_statistics.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/statistics, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerability_statistics.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/statistics, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerability_statistics.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/statistics, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.search_asset_vulnerability_statistics.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/statistics, respond with HTTP 401

## api.assets.v1.test_helpers.vulnerability.update_asset_vulnerability module

`api.assets.v1.test_helpers.vulnerability.update_asset_vulnerability.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 403

`api.assets.v1.test_helpers.vulnerability.update_asset_vulnerability.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 404

`api.assets.v1.test_helpers.vulnerability.update_asset_vulnerability.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 200

`api.assets.v1.test_helpers.vulnerability.update_asset_vulnerability.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/vulnerability/w+, respond with HTTP 401

## Module contents